@@ -12,24 +12,20 @@ from .commandPSD6SmoothFlow import *
 pumps = []
 pumpLength = 16
 
-def communicationInitialization(port, baudrate):
-    init_serial(port, baudrate)
+def connect(port, baudrate):
+    initializeSerial(port, baudrate)
 
+def disconnect():
+    disconnectSerial()
 
 def executeCommand(pump, command, waitForPump=False):
-    send_command(pump.asciiAddress, command, waitForPump)
-
+    sendCommand(pump.asciiAddress, command, waitForPump)
 
 def definePump(address: str, type: util.PSDTypes, baudRate=9600, resolutionMode=0):
     if len(pumps) < pumpLength:
         newPump = PSD(address, type, baudRate, resolutionMode)
-        send_command(newPump.asciiAddress, newPump.command.hEnableFactorCommands(True) + newPump.command.executeCommandBuffer())
-        result = send_command(newPump.asciiAddress, newPump.command.syringeModeQuery(), True)
+        sendCommand(newPump.asciiAddress, newPump.command.hEnableFactorCommands(True) + newPump.command.executeCommandBuffer())
+        result = sendCommand(newPump.asciiAddress, newPump.command.syringeModeQuery(), True)
         resolution = result[3:4]
         newPump.setResolution(int(resolution))
-        pumps.append(newPump)
-
-
-
-
-
+        pumps.append(newPump)
\ No newline at end of file
