@@ -5,9 +5,22 @@ import time
 ser = 0
 ComPort = 'COM'
 
+statusBytesInfo = {
+    '@': "Pump is busy - no error",
+    '`': "Pump is ready - no error",
+    'a': "Initialization error – occurs when the pump fails to initialize",
+    'b': "Invalid command – occurs when an unrecognized command is used.",
+    'c': "Invalid operand – occurs when and invalid parameter is given with a command.",
+    'd': "Invalid command sequence – occurs when the command communication protocol is incorrect",
+    'f': "EEPROM failure – occurs when the EEPROM is faulty",
+    'g': "Syringe not initialized – occurs when the syringe fails to initialize",
+    'i': "Syringe overload – occurs when the syringe encounters excessive back pressure.",
+    'j': "Valve overload – occurs when the valve drive encounters excessive back pressure.",
+    'k': "Syringe move not allowed – when the valve is in the bypass or throughput position, syringe move commands are not allowed.",
+    'o': "Pump is busy – occurs when the command buffer is full"
+}
 
-# Function to Initialize the Serial Port
-def init_serial(commPort: int, baudrate: int):
+def initializeSerial(commPort: int, baudrate: int):
     global ser
     ser = serial.Serial()
     ser.port = ComPort + str(commPort)
@@ -27,64 +40,51 @@ def init_serial(commPort: int, baudrate: int):
     if ser.isOpen():
         print('Open: ' + ser.portstr)
 
+def disconnectSerial():
+    if ser.isOpen():
+        ser.close()
 
-# Function Ends Here
-
-
-def encode_command(message: str):
+def encodeCommand(message: str):
     temp = message + '\r\n'
     encoded_temp = str.encode(temp)
     ser.write(encoded_temp)
 
     respondbytes = ser.readline()  # Read from Serial Port
-    print(respondbytes)
     decoded_temp = respondbytes.decode()
-    print('Response :')
-    print(decoded_temp)
-
+    print('Response :' + decoded_temp)
 
 def waitForResponse(header: str, footer: str):
+    print("Waiting for pump status ..")
     while True:
-        print("inside while")
         time.sleep(0.2)
         temp = header + "QR" + footer
         encoded_temp = str.encode(temp)
         ser.write(encoded_temp)
         respond_bytes = ser.readline()
-        print(respond_bytes)
         decoded_temp = respond_bytes.decode()
-        print("Response for Q command:")
-        print(decoded_temp)
         time.sleep(0.2)
-        new_character = decoded_temp[2:3]
-        print("print response bit")
-        print(new_character)
-        if new_character == '`':
-            print("break")
+        responseBit = decoded_temp[2:3]
+        print("Pump status: " + responseBit + ' - ' + statusBytesInfo[responseBit])
+        if responseBit == '`':
             break
 
-
 def executeCommand(pump, command, waitForPump=False):
     #pump.checkValidity()
-    return send_command(pump.asciiAddress, command, waitForPump)
+    return sendCommand(pump.asciiAddress, command, waitForPump)
 
-
-def send_command(pumpAddress: str, message: str, waitForPump=False):
+def sendCommand(pumpAddress: str, message: str, waitForPump=False):
     commandHeader = '/' + pumpAddress
     commandFooter = '\r\n'
 
     command = commandHeader + message + commandFooter
-    print("Command: " + command)
+    print("Sending command " + command)
     encoded_command = str.encode(command)
     ser.write(encoded_command)
-    respondbytes2 = ser.readline()  # Read from Serial Port
-    print(respondbytes2)
-    response = respondbytes2.decode()
-    print('Response :')
-    print(response)
+    respondbytes = ser.readline()  # Read from Serial Port
+    response = respondbytes.decode()
 
     if waitForPump:
         waitForResponse(commandHeader, commandFooter)
 
-    return response
-
+    print('Response :' + response)
+    return response
\ No newline at end of file
