@@ -1,4 +1,3 @@
-#from .util import *
 from .commandPSD4 import *
 from .commandPSD6 import *
 from .commandPSD4SmoothFlow import *
@@ -65,8 +64,8 @@ class PSD:
     def print(self):
         print("Address: " + self.asciiAddress)
         print("Type: " + str(self.type))
-        print("BaudRate: " + str(self.baudRate))
-        print("ResolutionMode: " + str(self.resolutionMode))
+        print("Baudrate: " + str(self.baudRate))
+        print("Resolution mode: " + str(self.resolutionMode))
         print("Command object: " + str(self.command))
 
     def checkValidity(self):
